@@ -134,7 +134,7 @@ impl<'state> State {
 	}
 
 	/// Finishes an [`Event`], adding it to `self.history`.
-	pub(crate) fn end_event(&mut self, start: Start, status: Status) -> Receipt {
+	pub fn end_event(&mut self, start: Start, status: Status) -> Receipt {
 		
 		let time = SystemTime::now();
 		let place = Place::new(&self.page, self.index);
